﻿// Copyright (C) Microsoft Corporation. All Rights Reserved.
// This code released under the terms of the Microsoft Public License
// (Ms-PL, http://opensource.org/licenses/ms-pl.html).

using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace PluginSizeMatchingComparison
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }

        private void HostContentNoResize_Click(object sender, RoutedEventArgs e)
        {
            var root = Application.Current.Host.Content;
            var popup = new Popup();
            var child = CreateChildElement();
            child.Width = root.ActualWidth;
            child.Height = root.ActualHeight;
            MouseButtonEventHandler buttonDown = null;
            buttonDown = delegate
            {
                LayoutRoot.MouseLeftButtonDown -= buttonDown;
                popup.IsOpen = false;
            };
            LayoutRoot.MouseLeftButtonDown += buttonDown;
            popup.Child = child;
            popup.IsOpen = true;
        }

        private void HostContentResize_Click(object sender, RoutedEventArgs e)
        {
            var root = Application.Current.Host.Content;
            var popup = new Popup();
            var child = CreateChildElement();
            EventHandler rootResized = delegate
            {
                child.Width = root.ActualWidth;
                child.Height = root.ActualHeight;
            };
            root.Resized += rootResized;
            rootResized(null, null);
            MouseButtonEventHandler buttonDown = null;
            buttonDown = delegate
            {
                root.Resized -= rootResized;
                LayoutRoot.MouseLeftButtonDown -= buttonDown;
                popup.IsOpen = false;
            };
            LayoutRoot.MouseLeftButtonDown += buttonDown;
            popup.Child = child;
            popup.IsOpen = true;
        }

        private void RootVisualResize_Click(object sender, RoutedEventArgs e)
        {
            var root = Application.Current.RootVisual as FrameworkElement;
            var popup = new Popup();
            var child = CreateChildElement();
            SizeChangedEventHandler rootSizeChanged = delegate
            {
                child.Width = root.ActualWidth;
                child.Height = root.ActualHeight;
            };
            root.SizeChanged += rootSizeChanged;
            rootSizeChanged(null, null);
            MouseButtonEventHandler buttonDown = null;
            buttonDown = delegate
            {
                root.SizeChanged -= rootSizeChanged;
                LayoutRoot.MouseLeftButtonDown -= buttonDown;
                popup.IsOpen = false;
            };
            LayoutRoot.MouseLeftButtonDown += buttonDown;
            popup.Child = child;
            popup.IsOpen = true;
        }

        private FrameworkElement CreateChildElement()
        {
            return new Image
            {
                Source = new BitmapImage(new Uri("Silverlight.png", UriKind.Relative)),
                Stretch = Stretch.Fill,
                Opacity = 0.7,
                IsHitTestVisible = false,
            };
        }
    }
}
